@@ -43,6 +43,10 @@ def _newLinkFromWay(link_id, way, direction, ref_node_list):
             else:
                 link.lanes_list = [way.lanes]
 
+    for ref_node in ref_node_list[1:-1]:
+        if ref_node.ctrl_type == 'signal':
+            link.ctrl_type = 'signal'
+
     link.lanes = link.lanes_list[0]
     link.from_node = ref_node_list[0]
     link.to_node = ref_node_list[-1]
@@ -144,6 +148,15 @@ def _identifyPureCycleWays(link_way_list):
                     break
 
 
+def _addSignalFromLink(network):
+    for link_id, link in network.link_dict.items():
+        if link.ctrl_type == 'signal':
+            to_node = link.to_node
+            if to_node.ctrl_type != 'signal':
+                if len(to_node.incoming_link_list) > 1 or len(to_node.outgoing_link_list) > 1:
+                    to_node.ctrl_type = 'signal'
+
+
 def _getNetworkNodes(network):
     node_dict = {}
     max_node_id = network.max_node_id
@@ -356,6 +369,8 @@ def _createNLPs(network, link_type, offset, network_type, POIs, POI_percentage):
 
     _identifyPureCycleWays(link_way_list)
     _createLinks(network, link_way_list)
+    _addSignalFromLink(network)
+
     if offset != 'no': _offsetLinks(network, offset)
 
     if POIs: generatePOIs(POI_way_list, network, POI_percentage)
@@ -367,8 +382,10 @@ def _createNLPs(network, link_type, offset, network_type, POIs, POI_percentage):
 
 def _buildNet(network,network_type, link_type, POIs, POI_percentage, offset, min_nodes, combine, int_buffer, default_lanes, default_speed, default_capacity):
 
+    # update default lanes, speed, and capacity
     _updateDefaultLSC(default_lanes, default_speed, default_capacity, network)
 
+    # create node, link, poi
     _createNLPs(network, link_type, offset, network_type, POIs, POI_percentage)
 
     # remove isolated nodes and links
