@@ -1,5 +1,7 @@
 import csv
 import os
+import sys
+
 import osmium
 from .classes import *
 from shapely import geometry
@@ -197,8 +199,12 @@ def _processRelations(net, h):
 
 
 def _getBounds(filename, bbox):
-    if bbox is None:
+    try:
         f = osmium.io.Reader(filename)
+    except:
+        sys.exit(f'Error: filepath {filename} contains invalid characters. Please use english characters only')
+
+    if bbox is None:
         header = f.header()
         box = header.box()
         bottom_left = box.bottom_left
